package com.qmth.distributed.print.business.bean.dto.report;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * @Description: 课程目标权重dto
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2024/2/26
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
public class CourseTargetWeightDto implements Serializable {

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "课程目标id")
    private Long targetId;

    @ApiModelProperty(value = "课程目标名称")
    private String targetName;

    @ApiModelProperty(value = "毕业要求")
    private String graduationRequirement;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "评价方式id")
    private Long evaluationId;

    @ApiModelProperty(value = "评价方式")
    private String evaluation;

    @ApiModelProperty(value = "评价方式描述")
    private String evaluationDesc;

    @ApiModelProperty(value = "知识点集合")
    private List<DimensionDto> dimensionList;

    @ApiModelProperty(value = "平时成绩权重")
    private Map<String, BigDecimal> usualScoreWeight;

    @ApiModelProperty(value = "期末成绩权重")
    private BigDecimal finalScoreWeight;

    public CourseTargetWeightDto() {

    }

    public CourseTargetWeightDto(Long targetId, String targetName) {
        this.targetId = targetId;
        this.targetName = targetName;
    }


    public CourseTargetWeightDto(CourseTargetDto courseTargetDto) {
        this.targetId = courseTargetDto.getTargetId();
        this.targetName = courseTargetDto.getTargetName();
        this.graduationRequirement = courseTargetDto.getGraduationRequirement();
        this.evaluationId = courseTargetDto.getEvaluationId();
        this.evaluation = courseTargetDto.getEvaluation();
        this.evaluationDesc = courseTargetDto.getEvaluationDesc();
    }

    public CourseTargetWeightDto(Long targetId, String targetName, Map<String, BigDecimal> usualScoreWeight, BigDecimal finalScoreWeight) {
        this.targetId = targetId;
        this.targetName = targetName;
        this.usualScoreWeight = usualScoreWeight;
        this.finalScoreWeight = finalScoreWeight;
    }

    public String getGraduationRequirement() {
        return graduationRequirement;
    }

    public void setGraduationRequirement(String graduationRequirement) {
        this.graduationRequirement = graduationRequirement;
    }

    public Long getEvaluationId() {
        return evaluationId;
    }

    public void setEvaluationId(Long evaluationId) {
        this.evaluationId = evaluationId;
    }

    public String getEvaluation() {
        return evaluation;
    }

    public void setEvaluation(String evaluation) {
        this.evaluation = evaluation;
    }

    public String getEvaluationDesc() {
        return evaluationDesc;
    }

    public void setEvaluationDesc(String evaluationDesc) {
        this.evaluationDesc = evaluationDesc;
    }

    public List<DimensionDto> getDimensionList() {
        return dimensionList;
    }

    public void setDimensionList(List<DimensionDto> dimensionList) {
        this.dimensionList = dimensionList;
    }

    public Long getTargetId() {
        return targetId;
    }

    public void setTargetId(Long targetId) {
        this.targetId = targetId;
    }

    public String getTargetName() {
        return targetName;
    }

    public void setTargetName(String targetName) {
        this.targetName = targetName;
    }

    public Map<String, BigDecimal> getUsualScoreWeight() {
        return usualScoreWeight;
    }

    public void setUsualScoreWeight(Map<String, BigDecimal> usualScoreWeight) {
        this.usualScoreWeight = usualScoreWeight;
    }

    public BigDecimal getFinalScoreWeight() {
        return finalScoreWeight;
    }

    public void setFinalScoreWeight(BigDecimal finalScoreWeight) {
        this.finalScoreWeight = finalScoreWeight;
    }
}
